@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Config::INI;
+package Config::INI 0.028;
 # ABSTRACT: simple .ini-file format
-$Config::INI::VERSION = '0.026';
+
 #pod =head1 SYNOPSIS
 #pod
 #pod Config-INI comes with code for reading F<.ini> files:
@@ -93,7 +93,7 @@ Config::INI - simple .ini-file format
 
 =head1 VERSION
 
-version 0.026
+version 0.028
 
 =head1 SYNOPSIS
 
@@ -107,10 +107,10 @@ Config-INI comes with code for reading F<.ini> files:
 
 See L<Config::INI::Writer> and L<Config::INI::Reader> for more examples.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -181,11 +181,11 @@ Originaly derived from L<Config::Tiny>, by Adam Kennedy.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 CONTRIBUTORS
 
-=for stopwords castaway David Steinbrunner Florian Ragwitz George Hartzell Graham Knop Ricardo SIGNES Smylers
+=for stopwords castaway David Steinbrunner Florian Ragwitz George Hartzell Graham Knop Ricardo SIGNES Signes Smylers
 
 =over 4
 
@@ -215,6 +215,10 @@ Ricardo SIGNES <com.github@rjbs.manxome.org>
 
 =item *
 
+Ricardo Signes <rjbs@semiotic.systems>
+
+=item *
+
 Smylers <Smylers@stripey.com>
 
 =back
