@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package Config::INI::Reader;
-$Config::INI::Reader::VERSION = '0.026';
-use Mixin::Linewise::Readers 0.105;
+package Config::INI::Reader 0.028;
+
+use Mixin::Linewise::Readers 0.110;
 # ABSTRACT: a subclassable .ini-file parser
 
 #pod =head1 SYNOPSIS
@@ -319,7 +319,7 @@ Config::INI::Reader - a subclassable .ini-file parser
 
 =head1 VERSION
 
-version 0.026
+version 0.028
 
 =head1 SYNOPSIS
 
@@ -364,10 +364,10 @@ The chief difference is that Config::INI::Reader is designed to be subclassed
 to allow for side-effects and self-reconfiguration to occur during the course
 of reading its input.
 
-=head1 PERL VERSION SUPPORT
+=head1 PERL VERSION
 
-This module has a long-term perl support period.  That means it will not
-require a version of perl released fewer than five years ago.
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
 
 Although it may work on older versions of perl, no guarantee is made that the
 minimum required version will not be increased.  The version may be increased
@@ -502,7 +502,7 @@ Originaly derived from L<Config::Tiny>, by Adam Kennedy.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@semiotic.systems>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
